/**\file adc.h
 * \brief Analog Digital Wandler Funktionen
 *
 * Header Datei zur Ansteuerung des AnalodDgiitalConverters
 */
#ifndef ADC_H_
#define ADC_H_

#include <avr/io.h>

#define ADC0  0x0
#define ADC1  0x1
#define ADC2  0x2
#define ADC3  0x3

/**
 * \brief Initialisierung des ADCs
 *
 * Die Ports ADC0-ADC3 werden für den ADC reserviert und der ADC wird initialisiert.
 *
 */
void ADC_Init(void);

/**
 * \brief Abfrage eines ADC-Ports
 *
 * Fragt den digitalisierten aktuellen analogen Wert des Mikrocontrollerpins (ADC0-3) ab.
 *
 * \param channel der abzufragende Port(ADC0-ADC3)
 * \return Gibt einen 10-bit Wert zurück. eine Null entspricht GND-potential am abgefragten Port, der höchste Wert entspricht dem Potential der an am Pin AREF anliegenden Spannung, normalerweise Betriebsspannung 5V. Es ergibt sich also die Formel(ADC entspricht dem Rückgabewert der Funktion): Vin=(ADC*Varef)/1024
 */
unsigned short ADCReadChannel(unsigned char channel);


#endif /* ADC_H_ */
