/** \file motor.h
 * \brief Motoransteuerung
 *
 *Headerdatei für die die Ansteuerung von zwei Gleichstrommotoren
 *
 *
 */

/*
 * motor.h
 *
 *  Created on: 10.04.2009
 *      Author: tst
 */

#ifndef MOTOR_H_
#define MOTOR_H_
/**
 * \brief Initialiserung Motor A
 *
 * Richtet Timer und benötigte Pins für den Motor A ein.
 */
void initDCMotorA(void);

/**
 * \brief Initialiserung Motor B
 *
 * Richtet Timer und benötigte Pins für den Motor B ein.
 */
void initDCMotorB(void);


/**
 * \brief Ansteuerung Motor A in positiver Richtung
 *
 * Der Motor wird in "positiver" Richtung angesteuert. Positiv ist hier willkürlich für eine bessere Unterscheidung der beiden Drehrichtungen gewählt.
 * \param pwmValue Aussteuergrad des Motors. Kann zwischen 0 und 255 liegen. Bei 255 liegt annähernd die ungeregelte Spannung am Motor an.
 */
void motorAplus(unsigned char pwmValue);

/**
 * \brief Ansteuerung Motor A in negativer Richtung
 *
 * Der Motor wird in "negativer" Richtung angesteuert. Positiv ist hier willkürlich für eine bessere Unterscheidung der beiden Drehrichtungen gewählt.
 * \param pwmValue Aussteuergrad des Motors. Kann zwischen 0 und 255 liegen. Bei 255 liegt annähernd die ungeregelte Spannung am Motor an.
 */
void motorAminus(unsigned char pwmValue);


/**
 * \brief Ansteuerung Motor B in positiver Richtung
 *
 * Der Motor wird in "positiver" Richtung angesteuert. Positiv ist hier willkürlich für eine bessere Unterscheidung der beiden Drehrichtungen gewählt.
 * \param pwmValue Aussteuergrad des Motors. Kann zwischen 0 und 255 liegen. Bei 255 liegt annähernd die ungeregelte Spannung am Motor an.
 */
void motorBplus(unsigned char pwmValue);

/**
 * \brief Ansteuerung Motor B in negativer Richtung
 *
 * Der Motor wird in "negativer" Richtung angesteuert. Positiv ist hier willkürlich für eine bessere Unterscheidung der beiden Drehrichtungen gewählt.
 * \param pwmValue Aussteuergrad des Motors. Kann zwischen 0 und 255 liegen. Bei 255 liegt annähernd die ungeregelte Spannung am Motor an.
 */
void motorBminus(unsigned char pwmValue);




/**
 * \brief Initialisiert Timer1
 *
 * Stellt den Timer1 (mit seinen beiden "untertimer A und B" so ein, dass an OC1A und OC1B PWM genutz werden kann)
 * Diese Funktion sollte nur benutzt werden, wenn das PWM für eigene Zwecke gebraucht wird.
 * Zur Initialisierung der Motoransteuerung muss die Funktionen initDCMotorA bzw. initMotorB verwendet werden.
 */
void pwm_timer1_init(void);

/**
 * \brief Setzten des PWM-Wertes für OC1A
 *
 * Diese Funktion sollte nur benutzt werden, wenn das PWM für eigene Zwecke gabruacht wird.
 * Zur Steuerung eines Motors sollten die entsprechenden Funktionen verwendet werden.
 * \param value Aussteuerungsgrad der PWM
 */
void pwm_timer1A_set(unsigned char value);

/**
 * \brief Setzten des PWM-Wertes für OC1A
 *
 * Diese Funktion sollte nur benutzt werden, wenn das PWM für eigene Zwecke gabruacht wird.
 * Zur Steuerung eines Motors sollten die entsprechenden Funktionen verwendet werden.
 * \param value Aussteuerungsgrad der PWM
 */
void pwm_timer1B_set(unsigned char value);


#endif /* MOTOR_H_ */
