/** \file rtc.h
 * \brief Real-Time-Clock Funktionen
 *
 * In dieser Datei werden Funktionen zur Zeitmessung bereitgestellt.
 * Als Quelle dient Timer/Counter0. Wird diese Funktionalität genutzt, so dürfen keine Einstellungen, die diesen Zähler betreffen geändert werden.
 */

/*
 * rtc.h
 *
 *  Created on: 28.04.2010
 *      Author: Jan Ortner
 */

#ifndef RTC_H_
#define RTC_H_

#include <stdint.h>

/** \typedef time_t
 * \brief Typdefinition für Zeitstempel
 */

/** \struct time
 * \brief Struktur für Zeitstempel
 *
 * Die Struktur zum speichern von Zeitstempeln.
 *
 */
typedef struct time{/** Microsekunden 0-999 **/
	uint16_t us; /** Millisekunden 0-999 **/
	uint16_t ms; /** Minuten und Sekunden 0-3599. Einheit ist Sekunden **/
	uint16_t mins; /** Stunden 0-65535 **/
	uint16_t hd;
} time_t;

/**
 * \brief Initialisiert die Uhr.
 *
 * Der Zeitwert wird auf Null gesetzt, Timer0 und der zugehörigt Interrupt wird initialisiert.
 */
void initRTC();

/**
 * \brief Berechnet die Zeitdifferenz von zwei Zeitstempeln.
 *
 * Berechnet den Ausdruck terg=t1-t2.
 *  \param t1 Der größere (letzte) Zeitstempel
 *  \param t2 Der kleinere (frühere) Zeitstempel
 * 	\param terg Der Zeitstempel in den das Ergebnis geschrieben wird (kann gleich t1 oder t2 sein)
 *  \return 0 - erfolgreich, -1 - t1<t2 das Ergebnis ist unbrauchbar!
 */
int getTimeDiff(time_t* t1,time_t* t2,time_t* terg);

/**
 * \brief Speichert die aktuelle Zeit.
 *
 * Aktualisiert t auf den momentanen Zeitwert.
 * \param t Zeiger auf den Speicherbereich
 */
void getCurrentTime(time_t* t);


#endif /* RTC_H_ */
