/** \file uart_b.h
 * \brief UART (RS232) Funktionen (ohne Interrupt)
 *
 *Headerdatei für die Benutztung der blockierenden UART-Schnittstellen-Funktionen
 *
 *
 */

/* avr-lrs.h
 *
 *  Created on: 07.03.2009
 *      Author: tst
 */

#ifndef UART_B_H_
#define UART_B_H_

#include <avr/io.h>

/**
 * \brief Standard Initialisierung des UARTs.
 *
 * Initialisierung des uarts mit dem Standartwert UBRR=51
 * Bei einer Frequenz von 16MHz ergibt sich so eine Baudrate von 19,2k
 */
void init_uart_block_default(void);
/**
 * \brief Allgemeine Initialisierung des UARTs.
 *
 * Initialisierung mit einem über ubrr freiwählbarem Register UBRR
 * \param ubrr gewünschte UBRR initialisierung
 *
 */
void init_uart_block(uint16_t ubrr);

/**
 * \brief Schickt einzelnes Zeichen an den UART.
 *
 *Ein einzelnes Zeichen wird vom UART übertragen. Die Funktion springt erst bei Ende der Übertragung zurück.
 */
void putc_b(unsigned char);


/**
 * \brief Schicken eines Strings
 *
 *Schickt einen String über den UART. Die Funktion springt erst bei Ende der Übertragung zurück.
 * \param string Zeiger auf den zu sendenden Strings oder Datenblock.
 *
 */
void puts_b(char * string);

/**
 * \brief Schicken eines Strings oder Datenblocks.
 *
 *Schickt einen Block der Länge length über den UART. Die Funktion springt erst bei Ende der Übertragung zurück.
 * \param string Zeiger auf den zu sendenden Datenblock
 * \param length Anzahl der aus dem Speicherbereich data zu sendenden Bytes
 */
void puts_data_b(uint8_t * string, uint8_t length);

/**\brief Empfangen eines einzelnen Zeichens über den UART.
 *
 * Kehrt erst nach Empfang eines Bytes wieder zurück.
 * \return Gibt das empfangene Byte zurück.
 */
unsigned char getc_b();

/**\brief Empfangen eines einzelnen Zeichens über die UART-Schnittstelle.
 *
 * Kehrt erst nach Empfang eines Bytes oder einer Zeitüberschreitung zurück.
 * \param c Pointer auf das das gelesene Zeichen geschrieben werden soll
 * \param ms Timeout in Millisekunden
 * \return 0 - Timeout, 1 - Zeichen wurde empfangen.
 */
unsigned char getc_TO_b(char *c, int ms);






#endif /* UART_B_H_ */
